@@ -32,7 +32,7 @@ class browser:
         self.add_and_print_log('Creating browser', add_log)
 
         if (chrome):
-            self.driver = webdriver.Chrome(options)
+            self.driver = webdriver.Chrome(options=options)
         else:
             self.driver = webdriver.Firefox()
 
